@@ -2,10 +2,8 @@
 
 import re
 import time
-import random
 import warnings
 
-from hashlib import md5
 from vk.utils import make_handy
 
 try:
@@ -20,11 +18,9 @@ except ImportError:
 
 import requests
 
-
-def encode_for_signature(obj):
-    if isinstance(obj, (dict, list, tuple)):
-        obj = json.dumps(obj, ensure_ascii=False)
-    return obj
+# vk.com API Errors
+INTERNAL_SERVER_ERROR = 10  # Invalid access token
+CAPTCHA_IS_NEEDED = 14
 
 
 def json_iter_parse(response_text):
@@ -36,16 +32,21 @@ def json_iter_parse(response_text):
 
 
 class APISession(object):
-    def __init__(self, app_id, user_email=None, user_password=None, access_token=None, app_secret=None,
-                 scope='friends,photos,audio,video', timeout=1, api_version='5.20'):
+    def __init__(self, app_id=None, user_login=None, user_password=None, access_token=None, user_email=None,
+                 scope='offline', timeout=1, api_version='5.20'):
 
-        if (not user_email or not user_password) and not access_token and not app_secret:
-            raise ValueError('Arguments user_email and user_password, or token, or app_secret are required')
+        user_login = user_login or user_email
+
+        if (not user_login or not user_password) and not access_token:
+            raise ValueError('Arguments user_login and user_password, or access_token are required')
+
+        if user_email:  # deprecated at April 11, 2014
+            warnings.simplefilter('once')
+            warnings.warn("Use 'user_login' instead of deprecated 'user_email'", DeprecationWarning, stacklevel=2)
 
         self.app_id = app_id
-        self.app_secret = app_secret
 
-        self.user_email = user_email
+        self.user_login = user_login
         self.user_password = user_password
 
         self.access_token = access_token
@@ -61,7 +62,7 @@ class APISession(object):
             'Content-Type': 'application/x-www-form-urlencoded',
         }
 
-        if not access_token and user_email and user_password:
+        if not access_token and user_login and user_password:
             self.get_access_token()
 
     def get_access_token(self):
@@ -72,7 +73,7 @@ class APISession(object):
         login_data = {
             'act': 'login',
             'utf8': '1',
-            'email': self.user_email,
+            'email': self.user_login,
             'pass': self.user_password,
         }
 
@@ -110,8 +111,11 @@ class APISession(object):
                         json_data['error'],
                         json_data['error_description']
                     )
+                session.close()
                 raise VkAuthorizationError(error_message)
 
+        session.close()
+
         parsed_url = urlparse(response.url)
         token_dict = dict(parse_qsl(parsed_url.fragment))
         if 'access_token' in token_dict:
@@ -120,18 +124,20 @@ class APISession(object):
         else:
             raise VkAuthorizationError('OAuth2 authorization error')
 
-    def __getattr__(self, name):
-        return APIMethod(self, name)
+    def __getattr__(self, method_name):
+        return APIMethod(self, method_name)
 
     def __call__(self, method, timeout=None, **kwargs):
-        response = self._request(method, timeout=timeout, **kwargs)
+        response = self.method_request(method, timeout=timeout, **kwargs)
         response.raise_for_status()
 
         # there are may be 2 dicts in 1 json
         # for example: {'error': ...}{'response': ...}
         errors = []
+        error_codes = []
         for data in json_iter_parse(response.text):
             if 'error' in data:
+                error_codes.append(data['error']['error_code'])
                 errors.append(data['error'])
 
             if 'response' in data:
@@ -141,13 +147,13 @@ class APISession(object):
                 # return make_handy(data['response'])
                 return data['response']
             
-        if errors[0]['error_code'] == 10: # invalid access_token 
+        if INTERNAL_SERVER_ERROR in error_codes:  # invalid access token
             self.get_access_token()
             return self(method, timeout=timeout, **kwargs)
         else:
-            raise VkAPIError(errors[0])
+            raise VkAPIMethodError(errors[0])
 
-    def _request(self, method, timeout=None, **kwargs):
+    def method_request(self, method_name, timeout=None, **kwargs):
         if self.access_token:
             params = {
                 'access_token': self.access_token,
@@ -155,26 +161,12 @@ class APISession(object):
                 'v': self.api_version,
             }
             params.update(kwargs)
-            url = 'https://api.vk.com/method/' + method
-        else:
-            params = {
-                'api_id': str(self.app_id),
-                'method': method,
-                'format': 'JSON',
-                'v': self.api_version,
-                'random': random.randint(0, 2 ** 30),
-                'timestamp': int(time.time()),
-            }
-            params.update(kwargs)
-            params['sig'] = self._signature(params)
-            url = 'https://api.vk.com/api.php'
+            url = 'https://api.vk.com/method/' + method_name
+
         return self.session.post(url, params, timeout=timeout or self._timeout)
 
-    def _signature(self, params):
-        params = {key: encode_for_signature(value) for key, value in params.items()}
-        params_str = ''.join('{}={}'.format(key, value) for key, value in sorted(params.items()))
-        params_str += self.app_secret
-        return md5(params_str.encode('utf8')).hexdigest()
+    def captcha_is_needed(self, captcha_sid, captcha_img):
+        pass
 
 
 class APIMethod(object):
@@ -199,7 +191,7 @@ class VkAuthorizationError(VkError):
     pass
 
 
-class VkAPIError(VkError):
+class VkAPIMethodError(VkError):
     __slots__ = ['error']
 
     def __init__(self, error):
@@ -208,6 +200,3 @@ class VkAPIError(VkError):
 
     def __str__(self):
         return "{error_code}. {error_msg}. params = {request_params}".format(**self.error)
-
-
-API = APISession
